@@ -50,53 +50,19 @@ sub ACTION_install {
 
   # if no default set and this plugin has a score, or if this plugin
   # score higher than the existing default, then set default
-  set_default_handler($config, 'mp3', $mp3, $pkg);
-  set_default_handler($config, 'ogg', $ogg, $pkg);
+  if (! exists $config->{default}{mp3} and $mp3
+     or $mp3 and $mp3 >= $config->{default}{mp3}{score}) {
+    $config->{default}{mp3} = { name => $pkg, score => $mp3 };
+    warn "AudioFile::Info - Default mp3 handler is now $pkg\n";
+  }
+
+  if (! exists $config->{default}{ogg} and $ogg
+     or $ogg and $ogg >= $config->{default}{ogg}{score}) {
+    $config->{default}{ogg} = { name => $pkg, score => $ogg };
+    warn "AudioFile::Info - Default ogg handler is now $pkg\n";
+  }
 
   DumpFile($path, $config);
 }
 
-sub set_default_handler {
-  my ($config, $type, $val, $pkg) = @_;
-
-  if ($val and (not exists $config->{default}{$type}
-    or $val >= $config->{default}{$type}{score})) {
-    $config->{default}{$type} = { name => $pkg, score => $val };
-    warn "AudioFile::Info - Default $type handler is now $pkg\n";
-  }
-
-  return;
-}
-
 1;
-
-=head1 NAME
-
-AudioFile::Info::Build - Build utilities for AudioFile::Info.
-
-=head1 DESCRIPTION
-
-This is a module which is used as part of the build system for
-AudioFile::Info plugins.
-
-See L<AudioFile::Info> for more details.
-
-=head1 METHODS
-
-=head2 ACTION_install
-
-Overrides the ACTION_install method from Module::Build.
-
-=head1 AUTHOR
-
-Dave Cross, E<lt>dave@dave.org.ukE<gt>
-
-=head1 COPYRIGHT AND LICENSE
-
-Copyright 2003 by Dave Cross
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
-=cut
-
